@@ -4,7 +4,7 @@
 #### Check to see if OpenRC is PID 1 - otherwise just use sysvinit #### 
 #
 
-if [[ $(ps -p1 | grep -ic "openrc") -eq 1 ]]; then
+if [ $(ps -p1 | grep -ic openrc) -eq 1 ] || ( [ $(ps -p1 | grep -ic init) -eq 1 ] && [ $(init --version | grep -ic SysV ) -eq 0 ] && [ $(init --version | grep -ic Dinit ) -eq 0 ] ); then
 
 #######################################################################
 #-----Contents of OpenRC's original rcS script below-----
